# _*_ coding: utf-8 _*_
#
# hspylib v0.11.22
#
# Package: main.hspylib.addons.widman.widgets
"""Package initialization."""

__all__ = [
  'widget_free', 
  'widget_send_msg', 
  'widget_time_calc'
]
__version__ = '0.11.22'
